You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sis.apache.org by de...@apache.org on 2013/06/11 13:03:20 UTC

svn commit: r1491736 - in /sis/branches/JDK6: ./ application/ application/sis-app/ application/sis-console/ application/sis-console/src/main/java/org/apache/sis/console/ application/sis-webapp/ core/sis-build-helper/src/main/java/org/apache/sis/interna...

Author: desruisseaux
Date: Tue Jun 11 11:03:19 2013
New Revision: 1491736

URL: http://svn.apache.org/r1491736
Log:
Merge the "sis-app" module renaming from the JDK7 branch.

Added:
    sis/branches/JDK6/application/sis-console/   (props changed)
      - copied from r1491733, sis/branches/JDK7/application/sis-console/
    sis/branches/JDK6/ide-project/resources-links/org/apache/sis/console
      - copied unchanged from r1491733, sis/branches/JDK7/ide-project/resources-links/org/apache/sis/console
Removed:
    sis/branches/JDK6/application/sis-app/
    sis/branches/JDK6/ide-project/resources-links/org/apache/console
Modified:
    sis/branches/JDK6/   (props changed)
    sis/branches/JDK6/CHANGES
    sis/branches/JDK6/application/pom.xml
    sis/branches/JDK6/application/sis-console/pom.xml
    sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/Command.java
    sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/SubCommand.java
    sis/branches/JDK6/application/sis-webapp/pom.xml
    sis/branches/JDK6/core/sis-build-helper/src/main/java/org/apache/sis/internal/maven/BundleCreator.java
    sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.java
    sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.properties
    sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary_fr.properties
    sis/branches/JDK6/ide-project/NetBeans/nbproject/build-impl.xml
    sis/branches/JDK6/ide-project/NetBeans/nbproject/genfiles.properties
    sis/branches/JDK6/ide-project/NetBeans/nbproject/project.properties
    sis/branches/JDK6/ide-project/NetBeans/nbproject/project.xml
    sis/branches/JDK6/ide-project/eclipse/classpath
    sis/branches/JDK6/src/site/apt/index.apt

Propchange: sis/branches/JDK6/
------------------------------------------------------------------------------
  Merged /sis/branches/JDK7:r1491499-1491733

Modified: sis/branches/JDK6/CHANGES
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/CHANGES?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/CHANGES (original)
+++ sis/branches/JDK6/CHANGES Tue Jun 11 11:03:19 2013
@@ -3,6 +3,8 @@ Apache SIS Change Log
 
 Release 0.3 - Current Development
 
+* SIS-105: Renamed "sis-app" module as "sis-console".
+
 * SIS-103: Fix Eclipse errors in SIS (Travis Pinney via mattmann)
 
 * SIS-101 Moved QuadTree, GeoRSSData and related classes to their own package,

Modified: sis/branches/JDK6/application/pom.xml
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/application/pom.xml?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/application/pom.xml (original)
+++ sis/branches/JDK6/application/pom.xml Tue Jun 11 11:03:19 2013
@@ -86,11 +86,32 @@
 
 
   <!-- ===========================================================
+           Dependencies
+       =========================================================== -->
+  <dependencies>
+    <dependency>
+      <groupId>org.apache.sis.storage</groupId>
+      <artifactId>sis-storage</artifactId>
+      <version>${project.version}</version>
+    </dependency>
+
+    <!-- Test dependencies -->
+    <dependency>
+      <groupId>org.apache.sis</groupId>
+      <artifactId>sis-utility</artifactId>
+      <version>${project.version}</version>
+      <type>test-jar</type>
+      <scope>test</scope>
+    </dependency>
+  </dependencies>
+
+
+  <!-- ===========================================================
            Sub-modules included in the build in dependency order
        =========================================================== -->
   <modules>
     <module>sis-webapp</module>
-    <module>sis-app</module>
+    <module>sis-console</module>
   </modules>
 
 </project>

Propchange: sis/branches/JDK6/application/sis-console/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Tue Jun 11 11:03:19 2013
@@ -0,0 +1 @@
+target

Modified: sis/branches/JDK6/application/sis-console/pom.xml
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/application/sis-console/pom.xml?rev=1491736&r1=1491733&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/application/sis-console/pom.xml (original)
+++ sis/branches/JDK6/application/sis-console/pom.xml Tue Jun 11 11:03:19 2013
@@ -28,7 +28,7 @@
   <parent>
     <groupId>org.apache.sis</groupId>
     <artifactId>application</artifactId>
-    <version>0.3-jdk7-SNAPSHOT</version>
+    <version>0.3-jdk6-SNAPSHOT</version>
   </parent>
 
 

Modified: sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/Command.java
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/Command.java?rev=1491736&r1=1491733&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/Command.java [UTF-8] (original)
+++ sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/Command.java [UTF-8] Tue Jun 11 11:03:19 2013
@@ -106,12 +106,10 @@ public class Command implements Runnable
         if (commandName == null) {
             command = new HelpSC(-1, args);
         } else {
-            switch (commandName.toLowerCase(Locale.US)) {
-                case "about": command = new AboutSC(commandIndex, args); break;
-                case "help":  command = new HelpSC (commandIndex, args); break;
-                default: throw new InvalidCommandException(Errors.format(
-                            Errors.Keys.UnknownCommand_1, commandName), commandName);
-            }
+                 if (commandName.equalsIgnoreCase("about")) command = new AboutSC(commandIndex, args);
+            else if (commandName.equalsIgnoreCase("help"))  command = new HelpSC (commandIndex, args);
+            else throw new InvalidCommandException(Errors.format(
+                        Errors.Keys.UnknownCommand_1, commandName), commandName);
         }
     }
 

Modified: sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/SubCommand.java
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/SubCommand.java?rev=1491736&r1=1491733&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/SubCommand.java [UTF-8] (original)
+++ sis/branches/JDK6/application/sis-console/src/main/java/org/apache/sis/console/SubCommand.java [UTF-8] Tue Jun 11 11:03:19 2013
@@ -105,7 +105,7 @@ abstract class SubCommand implements Run
             throws InvalidOptionException
     {
         boolean isTest = false;
-        options = new EnumMap<>(Option.class);
+        options = new EnumMap<Option,String>(Option.class);
         for (int i=0; i<arguments.length; i++) {
             final String arg = arguments[i];
             if (i == commandIndex) {
@@ -145,7 +145,7 @@ abstract class SubCommand implements Run
         final boolean explicitEncoding;
         try {
             value = options.get(option = Option.LOCALE);
-            locale = (value != null) ? Locales.parse(value) : Locale.getDefault(Locale.Category.DISPLAY);
+            locale = (value != null) ? Locales.parse(value) : Locale.getDefault();
 
             value = options.get(option = Option.ENCODING);
             explicitEncoding = (value != null);

Modified: sis/branches/JDK6/application/sis-webapp/pom.xml
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/application/sis-webapp/pom.xml?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/application/sis-webapp/pom.xml (original)
+++ sis/branches/JDK6/application/sis-webapp/pom.xml Tue Jun 11 11:03:19 2013
@@ -52,11 +52,6 @@
            Omitting the declaration from the root pom.xml limits the inconvenience to this "sis-webapp"
            module only. -->
     </dependency>
-    <dependency>
-      <groupId>org.apache.sis.storage</groupId>
-      <artifactId>sis-storage</artifactId>
-      <version>${project.version}</version>
-    </dependency>
   </dependencies>
 
   <build>

Modified: sis/branches/JDK6/core/sis-build-helper/src/main/java/org/apache/sis/internal/maven/BundleCreator.java
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/core/sis-build-helper/src/main/java/org/apache/sis/internal/maven/BundleCreator.java?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.java [UTF-8] (original)
+++ sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.java [UTF-8] Tue Jun 11 11:03:19 2013
@@ -95,6 +95,11 @@ public final class Vocabulary extends In
         public static final int Code_1 = 21;
 
         /**
+         * Commands
+         */
+        public static final int Commands = 48;
+
+        /**
          * Current date and time
          */
         public static final int CurrentDateTime = 25;
@@ -220,6 +225,11 @@ public final class Vocabulary extends In
         public static final int OperatingSystem = 16;
 
         /**
+         * Options
+         */
+        public static final int Options = 49;
+
+        /**
          * Others
          */
         public static final int Others = 34;

Modified: sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.properties
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.properties?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.properties [ISO-8859-1] (original)
+++ sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.properties [ISO-8859-1] Tue Jun 11 11:03:19 2013
@@ -22,6 +22,7 @@ Attributes         = Attributes
 CharacterEncoding  = Character encoding
 Classpath          = Classpath
 Code_1             = {0} code
+Commands           = Commands
 CurrentDateTime    = Current date and time
 CurrentDirectory   = Current directory
 DaylightTime       = Daylight time
@@ -47,6 +48,7 @@ NumberOfNaN        = Number of \u2018NaN
 Of_3               = {0} ({1} of {2})
 Offset             = Offset
 OperatingSystem    = Operating system
+Options            = Options
 Others             = Others
 Paths              = Paths
 Root               = Root

Modified: sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary_fr.properties
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary_fr.properties?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary_fr.properties [ISO-8859-1] (original)
+++ sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary_fr.properties [ISO-8859-1] Tue Jun 11 11:03:19 2013
@@ -22,6 +22,7 @@ Attributes         = Attributs
 CharacterEncoding  = Encodage des caract\u00e8res
 Classpath          = Chemin de classes
 Code_1             = Code {0}
+Commands           = Commandes
 CurrentDateTime    = Date et heure courantes
 CurrentDirectory   = R\u00e9pertoire courant
 DaylightTime       = Heure normale
@@ -47,6 +48,7 @@ NumberOfNaN        = Nombre de \u2018NaN
 Of_3               = {0} ({1} de {2})
 Offset             = D\u00e9calage
 OperatingSystem    = Syst\u00e8me d'exploitation
+Options            = Options
 Others             = Autres
 Paths              = Chemins
 Root               = Racine

Modified: sis/branches/JDK6/ide-project/NetBeans/nbproject/build-impl.xml
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/ide-project/NetBeans/nbproject/build-impl.xml?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/ide-project/NetBeans/nbproject/build-impl.xml (original)
+++ sis/branches/JDK6/ide-project/NetBeans/nbproject/build-impl.xml Tue Jun 11 11:03:19 2013
@@ -135,7 +135,7 @@ is divided into following sections:
         </condition>
         <condition property="have.tests">
             <or>
-                <available file="${test.app.dir}"/>
+                <available file="${test.console.dir}"/>
                 <available file="${test.netcdf.dir}"/>
                 <available file="${test.storage.dir}"/>
                 <available file="${test.referencing.dir}"/>
@@ -147,7 +147,7 @@ is divided into following sections:
             <or>
                 <available file="${src.local-src.dir}"/>
                 <available file="${src.webapp.dir}"/>
-                <available file="${src.app.dir}"/>
+                <available file="${src.console.dir}"/>
                 <available file="${src.netcdf.dir}"/>
                 <available file="${src.storage.dir}"/>
                 <available file="${src.referencing.dir}"/>
@@ -243,14 +243,14 @@ is divided into following sections:
     <target depends="-pre-init,-init-private,-init-user,-init-project,-do-init" name="-init-check">
         <fail unless="src.local-src.dir">Must set src.local-src.dir</fail>
         <fail unless="src.webapp.dir">Must set src.webapp.dir</fail>
-        <fail unless="src.app.dir">Must set src.app.dir</fail>
+        <fail unless="src.console.dir">Must set src.console.dir</fail>
         <fail unless="src.netcdf.dir">Must set src.netcdf.dir</fail>
         <fail unless="src.storage.dir">Must set src.storage.dir</fail>
         <fail unless="src.referencing.dir">Must set src.referencing.dir</fail>
         <fail unless="src.metadata.dir">Must set src.metadata.dir</fail>
         <fail unless="src.utility.dir">Must set src.utility.dir</fail>
         <fail unless="src.resources.dir">Must set src.resources.dir</fail>
-        <fail unless="test.app.dir">Must set test.app.dir</fail>
+        <fail unless="test.console.dir">Must set test.console.dir</fail>
         <fail unless="test.netcdf.dir">Must set test.netcdf.dir</fail>
         <fail unless="test.storage.dir">Must set test.storage.dir</fail>
         <fail unless="test.referencing.dir">Must set test.referencing.dir</fail>
@@ -276,7 +276,7 @@ is divided into following sections:
     </target>
     <target depends="-init-ap-cmdline-properties" if="ap.supported.internal" name="-init-macrodef-javac-with-processors">
         <macrodef name="javac" uri="http://www.netbeans.org/ns/j2se-project/3">
-            <attribute default="${src.local-src.dir}:${src.webapp.dir}:${src.app.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}" name="srcdir"/>
+            <attribute default="${src.local-src.dir}:${src.webapp.dir}:${src.console.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}" name="srcdir"/>
             <attribute default="${build.classes.dir}" name="destdir"/>
             <attribute default="${javac.classpath}" name="classpath"/>
             <attribute default="${javac.processorpath}" name="processorpath"/>
@@ -316,7 +316,7 @@ is divided into following sections:
     </target>
     <target depends="-init-ap-cmdline-properties" name="-init-macrodef-javac-without-processors" unless="ap.supported.internal">
         <macrodef name="javac" uri="http://www.netbeans.org/ns/j2se-project/3">
-            <attribute default="${src.local-src.dir}:${src.webapp.dir}:${src.app.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}" name="srcdir"/>
+            <attribute default="${src.local-src.dir}:${src.webapp.dir}:${src.console.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}" name="srcdir"/>
             <attribute default="${build.classes.dir}" name="destdir"/>
             <attribute default="${javac.classpath}" name="classpath"/>
             <attribute default="${javac.processorpath}" name="processorpath"/>
@@ -348,7 +348,7 @@ is divided into following sections:
     </target>
     <target depends="-init-macrodef-javac-with-processors,-init-macrodef-javac-without-processors" name="-init-macrodef-javac">
         <macrodef name="depend" uri="http://www.netbeans.org/ns/j2se-project/3">
-            <attribute default="${src.local-src.dir}:${src.webapp.dir}:${src.app.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}" name="srcdir"/>
+            <attribute default="${src.local-src.dir}:${src.webapp.dir}:${src.console.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}" name="srcdir"/>
             <attribute default="${build.classes.dir}" name="destdir"/>
             <attribute default="${javac.classpath}" name="classpath"/>
             <sequential>
@@ -435,7 +435,7 @@ is divided into following sections:
                 <property name="junit.forkmode" value="perTest"/>
                 <junit dir="${work.dir}" errorproperty="tests.failed" failureproperty="tests.failed" fork="true" forkmode="${junit.forkmode}" showoutput="true" tempdir="${build.dir}">
                     <batchtest todir="${build.test.results.dir}">
-                        <fileset dir="${test.app.dir}" excludes="@{excludes},${excludes}" includes="@{includes}">
+                        <fileset dir="${test.console.dir}" excludes="@{excludes},${excludes}" includes="@{includes}">
                             <filename name="@{testincludes}"/>
                         </fileset>
                         <fileset dir="${test.netcdf.dir}" excludes="@{excludes},${excludes}" includes="@{includes}">
@@ -482,7 +482,7 @@ is divided into following sections:
                     <isset property="test.method"/>
                 </condition>
                 <union id="test.set">
-                    <fileset dir="${test.app.dir}" excludes="@{excludes},**/*.xml,${excludes}" includes="@{includes}">
+                    <fileset dir="${test.console.dir}" excludes="@{excludes},**/*.xml,${excludes}" includes="@{includes}">
                         <filename name="@{testincludes}"/>
                     </fileset>
                     <fileset dir="${test.netcdf.dir}" excludes="@{excludes},**/*.xml,${excludes}" includes="@{includes}">
@@ -609,7 +609,7 @@ is divided into following sections:
                 <property name="junit.forkmode" value="perTest"/>
                 <junit dir="${work.dir}" errorproperty="tests.failed" failureproperty="tests.failed" fork="true" forkmode="${junit.forkmode}" showoutput="true" tempdir="${build.dir}">
                     <batchtest todir="${build.test.results.dir}">
-                        <fileset dir="${test.app.dir}" excludes="@{excludes},${excludes}" includes="@{includes}">
+                        <fileset dir="${test.console.dir}" excludes="@{excludes},${excludes}" includes="@{includes}">
                             <filename name="@{testincludes}"/>
                         </fileset>
                         <fileset dir="${test.netcdf.dir}" excludes="@{excludes},${excludes}" includes="@{includes}">
@@ -991,14 +991,14 @@ is divided into following sections:
                 <include name="*"/>
             </dirset>
         </pathconvert>
-        <j2seproject3:depend srcdir="${src.local-src.dir}:${src.webapp.dir}:${src.app.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}:${build.generated.subdirs}"/>
+        <j2seproject3:depend srcdir="${src.local-src.dir}:${src.webapp.dir}:${src.console.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}:${build.generated.subdirs}"/>
     </target>
     <target depends="init,deps-jar,-pre-pre-compile,-pre-compile, -copy-persistence-xml,-compile-depend" if="have.sources" name="-do-compile">
         <j2seproject3:javac gensrcdir="${build.generated.sources.dir}"/>
         <copy todir="${build.classes.dir}">
             <fileset dir="${src.local-src.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${src.webapp.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
-            <fileset dir="${src.app.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
+            <fileset dir="${src.console.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${src.netcdf.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${src.storage.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${src.referencing.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
@@ -1025,7 +1025,7 @@ is divided into following sections:
     <target depends="init,deps-jar,-pre-pre-compile" name="-do-compile-single">
         <fail unless="javac.includes">Must select some files in the IDE or set javac.includes</fail>
         <j2seproject3:force-recompile/>
-        <j2seproject3:javac excludes="" gensrcdir="${build.generated.sources.dir}" includes="${javac.includes}" sourcepath="${src.local-src.dir}:${src.webapp.dir}:${src.app.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}"/>
+        <j2seproject3:javac excludes="" gensrcdir="${build.generated.sources.dir}" includes="${javac.includes}" sourcepath="${src.local-src.dir}:${src.webapp.dir}:${src.console.dir}:${src.netcdf.dir}:${src.storage.dir}:${src.referencing.dir}:${src.metadata.dir}:${src.utility.dir}:${src.resources.dir}"/>
     </target>
     <target name="-post-compile-single">
         <!-- Empty placeholder for easier customization. -->
@@ -1292,7 +1292,7 @@ is divided into following sections:
             <fileset dir="${src.webapp.dir}" excludes="*.java,${excludes}" includes="${includes}">
                 <filename name="**/*.java"/>
             </fileset>
-            <fileset dir="${src.app.dir}" excludes="*.java,${excludes}" includes="${includes}">
+            <fileset dir="${src.console.dir}" excludes="*.java,${excludes}" includes="${includes}">
                 <filename name="**/*.java"/>
             </fileset>
             <fileset dir="${src.netcdf.dir}" excludes="*.java,${excludes}" includes="${includes}">
@@ -1326,7 +1326,7 @@ is divided into following sections:
             <fileset dir="${src.webapp.dir}" excludes="${excludes}" includes="${includes}">
                 <filename name="**/doc-files/**"/>
             </fileset>
-            <fileset dir="${src.app.dir}" excludes="${excludes}" includes="${includes}">
+            <fileset dir="${src.console.dir}" excludes="${excludes}" includes="${includes}">
                 <filename name="**/doc-files/**"/>
             </fileset>
             <fileset dir="${src.netcdf.dir}" excludes="${excludes}" includes="${includes}">
@@ -1369,12 +1369,12 @@ is divided into following sections:
         <!-- You can override this target in the ../build.xml file. -->
     </target>
     <target if="do.depend.true" name="-compile-test-depend">
-        <j2seproject3:depend classpath="${javac.test.classpath}" destdir="${build.test.classes.dir}" srcdir="${test.app.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}"/>
+        <j2seproject3:depend classpath="${javac.test.classpath}" destdir="${build.test.classes.dir}" srcdir="${test.console.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}"/>
     </target>
     <target depends="init,deps-jar,compile,-pre-pre-compile-test,-pre-compile-test,-compile-test-depend" if="have.tests" name="-do-compile-test">
-        <j2seproject3:javac apgeneratedsrcdir="${build.test.classes.dir}" classpath="${javac.test.classpath}" debug="true" destdir="${build.test.classes.dir}" processorpath="${javac.test.processorpath}" srcdir="${test.app.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}"/>
+        <j2seproject3:javac apgeneratedsrcdir="${build.test.classes.dir}" classpath="${javac.test.classpath}" debug="true" destdir="${build.test.classes.dir}" processorpath="${javac.test.processorpath}" srcdir="${test.console.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}"/>
         <copy todir="${build.test.classes.dir}">
-            <fileset dir="${test.app.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
+            <fileset dir="${test.console.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${test.netcdf.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${test.storage.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${test.referencing.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
@@ -1394,9 +1394,9 @@ is divided into following sections:
     <target depends="init,deps-jar,compile,-pre-pre-compile-test,-pre-compile-test-single" if="have.tests" name="-do-compile-test-single">
         <fail unless="javac.includes">Must select some files in the IDE or set javac.includes</fail>
         <j2seproject3:force-recompile destdir="${build.test.classes.dir}"/>
-        <j2seproject3:javac apgeneratedsrcdir="${build.test.classes.dir}" classpath="${javac.test.classpath}" debug="true" destdir="${build.test.classes.dir}" excludes="" includes="${javac.includes}" processorpath="${javac.test.processorpath}" sourcepath="${test.app.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}" srcdir="${test.app.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}"/>
+        <j2seproject3:javac apgeneratedsrcdir="${build.test.classes.dir}" classpath="${javac.test.classpath}" debug="true" destdir="${build.test.classes.dir}" excludes="" includes="${javac.includes}" processorpath="${javac.test.processorpath}" sourcepath="${test.console.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}" srcdir="${test.console.dir}:${test.netcdf.dir}:${test.storage.dir}:${test.referencing.dir}:${test.metadata.dir}:${test.utility.dir}"/>
         <copy todir="${build.test.classes.dir}">
-            <fileset dir="${test.app.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
+            <fileset dir="${test.console.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${test.netcdf.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${test.storage.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>
             <fileset dir="${test.referencing.dir}" excludes="${build.classes.excludes},${excludes}" includes="${includes}"/>

Modified: sis/branches/JDK6/ide-project/NetBeans/nbproject/genfiles.properties
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/ide-project/NetBeans/nbproject/genfiles.properties?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/ide-project/NetBeans/nbproject/genfiles.properties [ISO-8859-1] (original)
+++ sis/branches/JDK6/ide-project/NetBeans/nbproject/genfiles.properties [ISO-8859-1] Tue Jun 11 11:03:19 2013
@@ -3,6 +3,6 @@
 build.xml.data.CRC32=58e6b21c
 build.xml.script.CRC32=462eaba0
 build.xml.stylesheet.CRC32=28e38971@1.53.1.46
-nbproject/build-impl.xml.data.CRC32=3d12ef07
-nbproject/build-impl.xml.script.CRC32=abdc264a
+nbproject/build-impl.xml.data.CRC32=ca153f28
+nbproject/build-impl.xml.script.CRC32=cd693ddf
 nbproject/build-impl.xml.stylesheet.CRC32=c6d2a60f@1.56.1.46

Modified: sis/branches/JDK6/ide-project/NetBeans/nbproject/project.properties
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/ide-project/NetBeans/nbproject/project.properties?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/ide-project/NetBeans/nbproject/project.properties [ISO-8859-1] (original)
+++ sis/branches/JDK6/ide-project/NetBeans/nbproject/project.properties [ISO-8859-1] Tue Jun 11 11:03:19 2013
@@ -28,8 +28,8 @@ project.root         = ../..
 src.local-src.dir    = ../local-src
 src.resources.dir    = ../resources-links
 src.webapp.dir       = ${project.root}/application/sis-webapp/src/main/java
-src.app.dir          = ${project.root}/application/sis-app/src/main/java
-test.app.dir         = ${project.root}/application/sis-app/src/test/java
+src.console.dir      = ${project.root}/application/sis-console/src/main/java
+test.console.dir     = ${project.root}/application/sis-console/src/test/java
 src.netcdf.dir       = ${project.root}/storage/sis-netcdf/src/main/java
 test.netcdf.dir      = ${project.root}/storage/sis-netcdf/src/test/java
 src.storage.dir      = ${project.root}/storage/sis-storage/src/main/java

Modified: sis/branches/JDK6/ide-project/NetBeans/nbproject/project.xml
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/ide-project/NetBeans/nbproject/project.xml?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/ide-project/NetBeans/nbproject/project.xml (original)
+++ sis/branches/JDK6/ide-project/NetBeans/nbproject/project.xml Tue Jun 11 11:03:19 2013
@@ -7,7 +7,7 @@
             <source-roots>
                 <root id="src.local-src.dir" name="Local sources (unversioned)"/>
                 <root id="src.webapp.dir" name="Web application"/>
-                <root id="src.app.dir" name="Application"/>
+                <root id="src.console.dir" name="Console"/>
                 <root id="src.netcdf.dir" name="NetCDF"/>
                 <root id="src.storage.dir" name="Storage"/>
                 <root id="src.referencing.dir" name="Referencing"/>
@@ -16,7 +16,7 @@
                 <root id="src.resources.dir" name="Resources"/>
             </source-roots>
             <test-roots>
-                <root id="test.app.dir" name="Test Application"/>
+                <root id="test.console.dir" name="Test Console"/>
                 <root id="test.netcdf.dir" name="Test NetCDF"/>
                 <root id="test.storage.dir" name="Test Storage"/>
                 <root id="test.referencing.dir" name="Test Referencing"/>

Modified: sis/branches/JDK6/ide-project/eclipse/classpath
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/ide-project/eclipse/classpath?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/ide-project/eclipse/classpath (original)
+++ sis/branches/JDK6/ide-project/eclipse/classpath Tue Jun 11 11:03:19 2013
@@ -2,7 +2,7 @@
 <classpath>
 	<classpathentry kind="src" path="trunk/application/sis-webapp/src/main/java"/>
 	<classpathentry kind="src" path="trunk/application/sis-webapp/src/main/resources"/>
-	<classpathentry kind="src" path="trunk/application/sis-app/src/main/java"/>
+	<classpathentry kind="src" path="trunk/application/sis-console/src/main/java"/>
 	<classpathentry kind="src" path="trunk/core/sis-build-helper/src/main/java"/>
 	<classpathentry kind="src" path="trunk/core/sis-build-helper/src/main/resources"/>
 	<classpathentry kind="src" path="trunk/core/sis-build-helper/src/main/javadoc"/>

Modified: sis/branches/JDK6/src/site/apt/index.apt
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/src/site/apt/index.apt?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================
--- sis/branches/JDK6/src/site/apt/index.apt [UTF-8] (original)
+++ sis/branches/JDK6/src/site/apt/index.apt [UTF-8] Tue Jun 11 11:03:19 2013
@@ -29,6 +29,10 @@ The Apache SIS™ library
   The latest release is <<<0.2-incubating>>>.
   The version under development is <<<0.3-geoapi3.0-SNAPSHOT>>>.
 
+  The source code can be checked out anonymously with SubVersion from
+  {{{http://svn.apache.org/repos/asf/sis/trunk}http://svn.apache.org/repos/asf/sis/trunk}},
+  or can be cloned with Git from {{{git://git.apache.org/sis.git}git://git.apache.org/sis.git}}.
+
 
 * Documentation
--- sis/branches/JDK6/core/sis-build-helper/src/main/java/org/apache/sis/internal/maven/BundleCreator.java [UTF-8] (original)
+++ sis/branches/JDK6/core/sis-build-helper/src/main/java/org/apache/sis/internal/maven/BundleCreator.java [UTF-8] Tue Jun 11 11:03:19 2013
@@ -41,9 +41,16 @@ import org.apache.maven.plugin.MojoExecu
  */
 public class BundleCreator extends AbstractMojo {
     /**
      * The Apache SIS version.
      */
-    private static final String VERSION = "0.3-jdk6";
+    private static final String VERSION = "0.3";
+
+    /**
+     * The Apache SIS branch for which this plugin is creating a bundle.
+     * This is declared as a separated constant in order to make easier to update
+     * {@link #VERSION} without creating conflicts during branch merge.
+     */
+    private static final String BRANCH = "jdk6";
 
     /**
      * The root directory (without the "<code>target/binaries</code>" sub-directory) where JARs
@@ -66,8 +73,9 @@ public class BundleCreator extends Abstr
             throw new MojoExecutionException("Directory not found: " + targetDirectory);
         }
         try {
-            final Packer packer = new Packer(targetDirectory, VERSION);
-            packer.addPack("sis-" + VERSION + ".jar");
+            final String fullVersion = VERSION + '-' + BRANCH;
+            final Packer packer = new Packer(targetDirectory, fullVersion);
+            packer.addPack("sis-" + fullVersion + ".jar");
             try {
                 packer.createJars();
             } finally {
@@ -41,9 +41,16 @@ import org.apache.maven.plugin.MojoExecu
 public class BundleCreator extends AbstractMojo {
     /**
-     * The Apache SIS version.
+     * The Apache SIS version, without branch name.
      */

Modified: sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.java
URL: http://svn.apache.org/viewvc/sis/branches/JDK6/core/sis-utility/src/main/java/org/apache/sis/util/resources/Vocabulary.java?rev=1491736&r1=1491735&r2=1491736&view=diff
==============================================================================